<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	
	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
	
	// echo $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Test data
	$test_array = array("one" => "One","two" => "Two","three" => "Three","four" => "Four","five" => "Five");
	
	// Multicheck Array
	$multicheck_array = array("one" => "French Toast", "two" => "Pancake", "three" => "Omelette", "four" => "Crepe", "five" => "Waffle");
	
	// Multicheck Defaults
	$multicheck_defaults = array("one" => "1","five" => "1");
	
	// Background Defaults
	
	$background_defaults = array('color' => '', 'image' => '', 'repeat' => 'repeat','position' => 'top center','attachment'=>'scroll');
	
	
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_bloginfo('stylesheet_directory') . '/images/';
		
	$options = array();
	
	
	$options[] = array( "name" => "General ",
						"type" => "heading");	
						
	$options[] = array( "name" => "استفاده از تصویر لوگو؟",
						"desc" => "اگر می‌خواهید از یک تصویر لوگو استفاده کنید تیک بزنید.",
						"id" => "w2f_logo",
						"std" => "1",
						"type" => "checkbox");		
		
	$options[] = array( "name" => "تصویر لوگو سایت",
						"desc" => "تصویر لوگوی خود را بارگذاری کنید.",
						"id" => "w2f_logopic",
						"std" => get_bloginfo('template_url') ."/images/logo.png",
						"type" => "upload");	
		
	$options[] = array( "name" => "شناسه توئیتر",
						"desc" => "شناسه توئیتر خود را وارد کنید.",
						"id" => "w2f_twitter",
						"std" => "twitter",
						"type" => "text");		

	$options[] = array( "name" => "فیسبوک",
						"desc" => "آدرس صفحه فیسبوک خود را وارد کنید.",
						"id" => "w2f_facebook",
						"std" => "",
						"type" => "text");							
							
	$options[] = array( "name" => "گوگل پلاس",
						"desc" => "پیوند گوگل پلاس خود را وارد نمایید. از http://gplus.to/ استفاده کنید",
						"id" => "w2f_google",
						"std" => "",
						"type" => "text");			
		
	$options[] = array( "name" => "Linkedin",
						"desc" => "پیوند Linkedin خود را وارد نمایید.",
						"id" => "w2f_linkedin",
						"std" => "",
						"type" => "text");			
		
		
	$options[] = array( "name" => "Homepage ",
						"type" => "heading");			
		
	$options[] = array( "name" => "اسلایدر تصاویر شاخص",
						"desc" => "اگر می‌خواهید اسلایدر شاخص را نمایش دهید تیک بزنید.",
						"id" => "w2f_feat_slide",
						"std" => "1",
						"type" => "checkbox");			
		
		
	$options[] = array( "name" => "دسته اسلایدر شاخص",
						"desc" => "دسته‌ای برای اسلایدر شاخص انتخاب کنید",
						"id" => "w2f_slide_categories",
						"type" => "select",
						"options" => $options_categories);		
		
	$options[] = array( "name" => "تعداد آیتم‌های اسلایدر",
						"desc" => "تعداد آیتم‌های اسلایدر شاخص را تنظیم کنید.",
						"id" => "w2f_slide_number",
						"std" => "4",
						"class" => "mini",
						"type" => "text");	
							
						
	$options[] = array( "name" => "قسمت متن راهنما",
						"desc" => "اگر می‌خواهید قسمت نوشته راهنما را نشان دهید اینجا را تیک بزنید.",
						"id" => "w2f_callout_box",
						"std" => "1",
						"type" => "checkbox");	
	
	$options[] = array( "name" => "محتوی قسمت نوشته راهنما",
						"desc" => "محتوی نشان داده شوند در قسمت نوشته راهنما را وارد نمایید",
						"id" => "w2f_callout",
						"type" => "textarea");		
	
	$options[] = array( "name" => "برگه نمونه‌کارها",
						"desc" => "برگه نمونه‌کارها را انتخاب کنید",
						"id" => "w2f_port_page",
						"type" => "select",
						"options" => $options_pages);		
	
	$options[] = array( "name" => "برگه وبلاگ",
						"desc" => "برگه وبلاگ را انتخاب کنید کنید",
						"id" => "w2f_blog_page",
						"type" => "select",
						"options" => $options_pages);	

						
	$options[] = array( "name" => "Banners",
						"type" => "heading");		
						
						
	$options[] = array( "name" => "تصویر بنر 1",
						"desc" => "Enter your 125 x 125 banner image url here..",
						"id" => "w2f_banner1",
						"std" => "http://temphaa.com/wp-content/themes/temphaa-v2.0/images/ads/temphaa125-125.gif",
						"type" => "text");		
						
	$options[] = array( "name" => "تگ توضیحات تصویر بنر 1",
						"desc" => "تگ توضیحات بنر خود را وارد کنید.",
						"id" => "w2f_alt1",
						"std" => "تمپــــ‌ها",
						"type" => "text");		
						
	$options[] = array( "name" => "آدرس بنر 1",
						"desc" => "آدرس بنر خود را وارد نمایید.",
						"id" => "w2f_url1",
						"std" => "http://temphaa.com/",
						"type" => "text");						
						
	$options[] = array( "name" => "عنوان پیوند بنر 1",
						"desc" => "عنوان بنر خود را وارد کنید.",
						"id" => "w2f_lab1",
						"std" => "تمپــــ‌‌ها.",
						"type" => "text");						
						


					$options[] = array( "name" => "تصویر بنر 2",
										"desc" => "آدرس تصویر بنر 125 x 125 خود را وارد کنید.",
										"id" => "w2f_banner2",
										"std" => "http://temphaa.com/wp-content/themes/temphaa-v2.0/images/ads/temphaa125-125.gif",
										"type" => "text");		

					$options[] = array( "name" => "تگ توضیحات تصویر بنر 2",
										"desc" => "تگ توضیحات بنر خود را وارد کنید.",
										"id" => "w2f_alt2",
										"std" => "تمپــــ‌ها",
										"type" => "text");		

					$options[] = array( "name" => "آدرس بنر 2",
										"desc" => "آدرس بنر خود را وارد نمایید.",
										"id" => "w2f_url2",
										"std" => "http://temphaa.com/",
										"type" => "text");						

					$options[] = array( "name" => "عنوان پیوند بنر 2",
										"desc" => "عنوان بنر خود را وارد کنید.",
										"id" => "w2f_lab2",
										"std" => "تمپــــ‌‌ها.",
										"type" => "text");
										
										
																
									$options[] = array( "name" => "تصویر بنر 3",
														"desc" => "آدرس تصویر بنر 125 x 125 خود را وارد کنید.",
														"id" => "w2f_banner3",
														"std" => "http://dl.wordpress98.com/2011/05/125125.gif",
														"type" => "text");		

									$options[] = array( "name" => "تگ توضیحات تصویر بنر 3",
														"desc" => "تگ توضیحات بنر خود را وارد کنید.",
														"id" => "w2f_alt3",
														"std" => "وردپرس98",
														"type" => "text");		

									$options[] = array( "name" => "آدرس بنر 3",
														"desc" => "آدرس بنر خود را وارد کنید.",
														"id" => "w2f_url3",
														"std" => "http://www.wordpress98.com/",
														"type" => "text");						

									$options[] = array( "name" => "عنوان پیوند بنر 3",
														"desc" => "عنوان بنر خود را وارد کنید.",
														"id" => "w2f_lab3",
														"std" => "وردپرس98.",
														"type" => "text");
														
														
														
																				
													$options[] = array( "name" => "تصویر بنر 4",
																		"desc" => "آدرس تصویر بنر 125 x 125 خود را وارد کنید.",
																		"id" => "w2f_banner4",
																		"std" => "http://dl.wordpress98.com/2011/05/125125.gif",
																		"type" => "text");		

													$options[] = array( "name" => "تگ توضیحات تصویر بنر 4",
																		"desc" => "تگ توضیحات بنر خود را وارد کنید.",
																		"id" => "w2f_alt4",
																		"std" => "وردپرس98",
																		"type" => "text");		

													$options[] = array( "name" => "آدرس بنر 4",
																		"desc" => "آدرس بنر خود را وارد نمایید.",
																		"id" => "w2f_url4",
																		"std" => "http://www.wordpress98.com",
																		"type" => "text");						

													$options[] = array( "name" => "عنوان پیوند بنر 4",
																		"desc" => "عنوان بنر خود را وارد کنید.",
																		"id" => "w2f_lab4",
																		"std" => "وردپرس98",
																		"type" => "text");						
						
						
						
						
								// 					
								// 					
								// 					
								// 					
								// 					
								// 	
								// $options[] = array( "name" => "Basic Settings",
								// 					"type" => "heading");
								// 						
								// $options[] = array( "name" => "Input Text Mini",
								// 					"desc" => "A mini text input field.",
								// 					"id" => "example_text_mini",
								// 					"std" => "Default",
								// 					"class" => "mini",
								// 					"type" => "text");
								// 							
								// $options[] = array( "name" => "Input Text",
								// 					"desc" => "A text input field.",
								// 					"id" => "example_text",
								// 					"std" => "Default Value",
								// 					"type" => "text");
								// 						
								// $options[] = array( "name" => "Textarea",
								// 					"desc" => "Textarea description.",
								// 					"id" => "example_textarea",
								// 					"std" => "Default Text",
								// 					"type" => "textarea"); 
								// 					
								// $options[] = array( "name" => "Input Select Small",
								// 					"desc" => "Small Select Box.",
								// 					"id" => "example_select",
								// 					"std" => "three",
								// 					"type" => "select",
								// 					"class" => "mini", //mini, tiny, small
								// 					"options" => $test_array);			 
								// 					
								// $options[] = array( "name" => "Input Select Wide",
								// 					"desc" => "A wider select box.",
								// 					"id" => "example_select_wide",
								// 					"std" => "two",
								// 					"type" => "select",
								// 					"options" => $test_array);
								// 					
								// $options[] = array( "name" => "Select a Category",
								// 					"desc" => "Passed an array of categories with cat_ID and cat_name",
								// 					"id" => "example_select_categories",
								// 					"type" => "select",
								// 					"options" => $options_categories);
								// 					
								// $options[] = array( "name" => "Select a Page",
								// 					"desc" => "Passed an pages with ID and post_title",
								// 					"id" => "example_select_pages",
								// 					"type" => "select",
								// 					"options" => $options_pages);
								// 					
								// $options[] = array( "name" => "Input Radio (one)",
								// 					"desc" => "Radio select with default options 'one'.",
								// 					"id" => "example_radio",
								// 					"std" => "one",
								// 					"type" => "radio",
								// 					"options" => $test_array);
								// 						
								// $options[] = array( "name" => "Example Info",
								// 					"desc" => "This is just some example information you can put in the panel.",
								// 					"type" => "info");
								// 										
								// $options[] = array( "name" => "Input Checkbox",
								// 					"desc" => "Example checkbox, defaults to true.",
								// 					"id" => "example_checkbox",
								// 					"std" => "1",
								// 					"type" => "checkbox");
								// 					
								// $options[] = array( "name" => "Advanced Settings",
								// 					"type" => "heading");
								// 					
								// $options[] = array( "name" => "Check to Show a Hidden Text Input",
								// 					"desc" => "Click here and see what happens.",
								// 					"id" => "example_showhidden",
								// 					"type" => "checkbox");
								// 
								// $options[] = array( "name" => "Hidden Text Input",
								// 					"desc" => "This option is hidden unless activated by a checkbox click.",
								// 					"id" => "example_text_hidden",
								// 					"std" => "Hello",
								// 					"class" => "hidden",
								// 					"type" => "text");
								// 					
								// $options[] = array( "name" => "Uploader Test",
								// 					"desc" => "This creates a full size uploader that previews the image.",
								// 					"id" => "example_uploader",
								// 					"type" => "upload");
								// 					
								// 
								// 					
								// $options[] = array( "name" =>  "Example Background",
								// 					"desc" => "Change the background CSS.",
								// 					"id" => "example_background",
								// 					"std" => $background_defaults, 
								// 					"type" => "background");
								// 							
								// $options[] = array( "name" => "Multicheck",
								// 					"desc" => "Multicheck description.",
								// 					"id" => "example_multicheck",
								// 					"std" => $multicheck_defaults, // These items get checked by default
								// 					"type" => "multicheck",
								// 					"options" => $multicheck_array);
								// 						
								// $options[] = array( "name" => "Colorpicker",
								// 					"desc" => "No color selected by default.",
								// 					"id" => "example_colorpicker",
								// 					"std" => "",
								// 					"type" => "color");
								// 					
								// $options[] = array( "name" => "Typography",
								// 					"desc" => "Example typography.",
								// 					"id" => "example_typography",
								// 					"std" => array('size' => '12px','face' => 'verdana','style' => 'bold italic','color' => '#123456'),
								// 					"type" => "typography");			
	return $options;
}